@@ -7,7 +7,8 @@ use cw_storage_plus::{Map};
 #[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
 pub struct SwapDetails {
     pub name: String,
-    pub address: String,
+    pub receiver: String,
+    pub swap_address: String,
     pub token1_amount: Uint128,
     pub code_id: u64
 }
